==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_sagemaker_a2i_runtime/paginator.py <==
"""
Type annotations for sagemaker-a2i-runtime service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_a2i_runtime/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_sagemaker_a2i_runtime.client import AugmentedAIRuntimeClient
    from types_boto3_sagemaker_a2i_runtime.paginator import (
        ListHumanLoopsPaginator,
    )

    session = Session()
    client: AugmentedAIRuntimeClient = session.client("sagemaker-a2i-runtime")

    list_human_loops_paginator: ListHumanLoopsPaginator = client.get_paginator("list_human_loops")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListHumanLoopsRequestListHumanLoopsPaginateTypeDef,
    ListHumanLoopsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListHumanLoopsPaginator",)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListHumanLoopsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-a2i-runtime/paginator/ListHumanLoops.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_a2i_runtime/paginators/#listhumanloopspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListHumanLoopsRequestListHumanLoopsPaginateTypeDef]
    ) -> _PageIterator[ListHumanLoopsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-a2i-runtime/paginator/ListHumanLoops.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_a2i_runtime/paginators/#listhumanloopspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_sagemaker_a2i_runtime/paginator.py <==
"""
Type annotations for sagemaker-a2i-runtime service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_a2i_runtime/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_sagemaker_a2i_runtime.client import AugmentedAIRuntimeClient
    from types_boto3_sagemaker_a2i_runtime.paginator import (
        ListHumanLoopsPaginator,
    )

    session = Session()
    client: AugmentedAIRuntimeClient = session.client("sagemaker-a2i-runtime")

    list_human_loops_paginator: ListHumanLoopsPaginator = client.get_paginator("list_human_loops")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListHumanLoopsRequestPaginateTypeDef, ListHumanLoopsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListHumanLoopsPaginator",)


if TYPE_CHECKING:
    _ListHumanLoopsPaginatorBase = Paginator[ListHumanLoopsResponseTypeDef]
else:
    _ListHumanLoopsPaginatorBase = Paginator  # type: ignore[assignment]


class ListHumanLoopsPaginator(_ListHumanLoopsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-a2i-runtime/paginator/ListHumanLoops.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_a2i_runtime/paginators/#listhumanloopspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListHumanLoopsRequestPaginateTypeDef]
    ) -> PageIterator[ListHumanLoopsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-a2i-runtime/paginator/ListHumanLoops.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_sagemaker_a2i_runtime/paginators/#listhumanloopspaginator)
        """
